---
c: Copyright (C) Daniel Stenberg, <daniel@haxx.se>, et al.
SPDX-License-Identifier: curl
Title: CURLINFO_SIZE_UPLOAD
Section: 3
Source: libcurl
See-also:
  - CURLINFO_SIZE_DOWNLOAD_T (3)
  - CURLINFO_SIZE_UPLOAD_T (3)
  - curl_easy_getinfo (3)
  - curl_easy_setopt (3)
Protocol:
  - All
---

# NAME

CURLINFO_SIZE_UPLOAD - get the number of uploaded bytes

# SYNOPSIS

~~~c
#include <curl/curl.h>

CURLcode curl_easy_getinfo(CURL *handle, CURLINFO_SIZE_UPLOAD,
                           double *uploadp);
~~~

# DESCRIPTION

Pass a pointer to a double to receive the total amount of bytes that were
uploaded.

CURLINFO_SIZE_UPLOAD_T(3) is a newer replacement that returns a more
sensible variable type.

# EXAMPLE

~~~c
int main(void)
{
  CURL *curl = curl_easy_init();
  if(curl) {
    CURLcode res;
    curl_easy_setopt(curl, CURLOPT_URL, "https://example.com");

    /* Perform the request */
    res = curl_easy_perform(curl);

    if(!res) {
      double ul;
      res = curl_easy_getinfo(curl, CURLINFO_SIZE_UPLOAD, &ul);
      if(!res) {
        printf("Uploaded %.0f bytes\n", ul);
      }
    }
  }
}
~~~

# AVAILABILITY

Added in 7.4.1. Deprecated since 7.55.0.

# RETURN VALUE

Returns CURLE_OK if the option is supported, and CURLE_UNKNOWN_OPTION if not.
