---
c: Copyright (C) Daniel Stenberg, <daniel@haxx.se>, et al.
SPDX-License-Identifier: curl
Title: CURLINFO_SPEED_UPLOAD
Section: 3
Source: libcurl
See-also:
  - CURLINFO_SPEED_DOWNLOAD_T (3)
  - curl_easy_getinfo (3)
  - curl_easy_setopt (3)
Protocol:
  - All
---

# NAME

CURLINFO_SPEED_UPLOAD - get upload speed

# SYNOPSIS

~~~c
#include <curl/curl.h>

CURLcode curl_easy_getinfo(CURL *handle, CURLINFO_SPEED_UPLOAD, double *speed);
~~~

# DESCRIPTION

Pass a pointer to a double to receive the average upload speed that curl
measured for the complete upload. Measured in bytes/second.

CURLINFO_SPEED_UPLOAD_T(3) is a newer replacement that returns a more
sensible variable type.

# EXAMPLE

~~~c
int main(void)
{
  CURL *curl = curl_easy_init();
  if(curl) {
    CURLcode res;
    curl_easy_setopt(curl, CURLOPT_URL, "https://example.com");

    /* Perform the request */
    res = curl_easy_perform(curl);

    if(!res) {
      double speed;
      res = curl_easy_getinfo(curl, CURLINFO_SPEED_UPLOAD, &speed);
      if(!res) {
        printf("Upload speed %.0f bytes/sec\n", speed);
      }
    }
  }
}
~~~

# AVAILABILITY

Added in 7.4.1. Deprecated since 7.55.0.

# RETURN VALUE

Returns CURLE_OK if the option is supported, and CURLE_UNKNOWN_OPTION if not.
